use argh::FromArgs;

use crate::{
    linux::{arch_chroot, systemd_service_enable},
    pkg::install_pkgs,
    print_status,
};

#[derive(FromArgs)]
#[argh(subcommand, name = "docker")]
/// Enable docker
pub struct DockerFeature {
    #[argh(positional)]
    /// assign user to docker group
    pub user: Vec<String>,
}

/// Setup docker on the system
pub fn setup_docker(conf: &[String]) {
    print_status("Setting up Docker");
    install_pkgs(&["docker", "docker-compose"]);

    systemd_service_enable("docker.service");

    for user in conf {
        arch_chroot(
            &vec!["usermod", "-a", "-G", "docker", user.as_str()],
            None,
            false,
        );
    }
}
