use argh::FromArgs;

use crate::{config::GPUVendor, pkg::install_pkgs};

#[derive(FromArgs)]
#[argh(subcommand, name = "gpu")]
/// Install GPU drivers
pub struct GPUFeature {
    #[argh(positional)]
    /// GPU vendor
    pub vendor: String,
}

/// Setup GPU video drivers
pub fn setup_video_drivers(vendor: &GPUVendor) {
    match vendor {
        GPUVendor::AMD => {
            install_pkgs(&[
                "xf86-video-amdgpu",
                "mesa",
                "lib32-mesa",
                "vulkan-radeon",
                "lib32-vulkan-radeon",
            ]);
        }
        GPUVendor::NVIDIA => {
            install_pkgs(&["nvidia", "nvidia-utils", "lib32-nvidia-utils"]);
        }
        GPUVendor::INTEL => {
            install_pkgs(&[
                "xf86-video-intel",
                "mesa",
                "lib32-mesa",
                "vulkan-intel",
                "lib32-vulkan-intel",
            ]);
        }
        GPUVendor::NONE => {}
    }
}
