use argh::FromArgs;

use crate::{
    linux::{arch_chroot, run_command_noerr, systemd_service_enable},
    pkg::install_pkgs,
    print_status,
};

#[derive(FromArgs)]
#[argh(subcommand, name = "virt-guest")]
/// Install VM guest utils
pub struct VirtGuestFeature {}

#[derive(FromArgs)]
#[argh(subcommand, name = "virt")]
/// Enable virtualization
pub struct VirtFeature {
    #[argh(switch)]
    /// enable virt-manager GUI
    pub gui: bool,

    #[argh(option)]
    /// add user to libvirt group
    pub user: Vec<String>,
}

pub fn setup_virtualization(conf: &VirtFeature) {
    install_pkgs(&["libvirt", "swtpm", "qemu-base"]);

    if conf.gui {
        install_pkgs(&["virt-manager"]);
    }

    systemd_service_enable("libvirtd.service");

    for user in &conf.user {
        arch_chroot(
            &vec!["usermod", "-a", "-G", "libvirt", user.as_str()],
            None,
            false,
        );
    }
}

pub fn setup_vm_guest() {
    print_status("Detected KVM. Installing utils");
    install_pkgs(&["qemu-guest-agent", "spice-vdagent"]);
    systemd_service_enable("qemu-guest-agent.service");
    systemd_service_enable("spice-vdagentd.service");
}

/// Setup guest utils if running inside a VM
pub fn try_setup_vm_guest() {
    let res = run_command_noerr(&["systemd-detect-virt", "--vm"], None, false);
    let is_vm = res.0.trim();

    match is_vm {
        "qemu" | "kvm" => {
            setup_vm_guest();
        }
        _ => {}
    }
}
